@@ -10,7 +10,7 @@ import { CSSProperties } from '@material-ui/core/styles/withStyles';
 import { Close, OpenInNew } from '@material-ui/icons';
 import * as React from 'react'
 import { Global } from '../../Global';
-import MuiDialogTitle from '@material-ui/core/DialogTitle';
+import DialogTitle from '@material-ui/core/DialogTitle';
 import { ShadowedDivider } from '../../core';
 import DataConnectorBrowser, { DataConnectorMetadata } from './dataConnectorBrowser/DataConnectorBrowser';
 import { Page } from '../UserDialog';
@@ -105,7 +105,7 @@ export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
 					onClose={this.handleClose}
                     scroll='paper'
 				>
-					<MuiDialogTitle
+					<DialogTitle
 					    disableTypography
                         style={{
                             display: 'inline-flex',
@@ -120,7 +120,7 @@ export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
                             width: '100%',
                             fontSize: '16px',
                             fontWeight: 'bold',
-                            paddingRight: '12px', // this is 6px counteracting the MuiDialogTitle padding and 6px aligning the padding to the right of the tabs
+                            paddingRight: '12px', // this is 6px counteracting the DialogTitle padding and 6px aligning the padding to the right of the tabs
                         }}>
                             <div style={{margin: 'auto 12px'}}>
             					Select Data Connectors
@@ -156,7 +156,7 @@ export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
                                 }}
                             />
                         </IconButton>
-					</MuiDialogTitle>
+					</DialogTitle>
                     <ShadowedDivider />
                     <DataConnectorBrowser style={{flexGrow: 1, height: '100%', maxHeight: 'calc(100% - 60px - 60px - 2px)'}} onAdd={this.handleAdd} getSelected={(getSelectedDataConnectors: () => DataConnectorMetadata[]) => this.getSelectedDataConnectors = getSelectedDataConnectors} />
                     <Divider />
