@@ -10,7 +10,7 @@ import { CSSProperties } from '@material-ui/core/styles/withStyles';
 import { Close } from '@material-ui/icons';
 import * as React from 'react'
 import { Global } from '../../Global';
-import MuiDialogTitle from '@material-ui/core/DialogTitle';
+import DialogTitle from '@material-ui/core/DialogTitle';
 import { ShadowedDivider } from '../../core';
 import FileBrowser, { FileMetadata } from './fileBrowser/FileBrowser';
 
@@ -103,7 +103,7 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
 					onClose={this.handleClose}
                     scroll='paper'
 				>
-					<MuiDialogTitle
+					<DialogTitle
 					    disableTypography
                         style={{
                             display: 'inline-flex',
@@ -118,7 +118,7 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
                             minWidth: '225px',
                             fontSize: '16px',
                             fontWeight: 'bold',
-                            paddingRight: '12px', // this is 6px counteracting the MuiDialogTitle padding and 6px aligning the padding to the right of the tabs
+                            paddingRight: '12px', // this is 6px counteracting the DialogTitle padding and 6px aligning the padding to the right of the tabs
                         }}>
                             <div style={{margin: 'auto', paddingLeft: '12px'}}>
             					Select Files or Directories
@@ -154,7 +154,7 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
                                 }}
                             />
                         </IconButton>
-					</MuiDialogTitle>
+					</DialogTitle>
                     <ShadowedDivider />
                     <FileBrowser style={{maxHeight: 'calc(100% - 60px - 2px)'}} onAdd={this.handleAdd} getSelectedFiles={(getSelectedFiles: () => FileMetadata[]) => this.getSelectedFiles = getSelectedFiles} />
 				</StyledDialog>
