@@ -12,6 +12,7 @@ import { Global } from '../../../Global';
 import { FileMetadata } from '../fileBrowser/FileBrowser';
 import DataConnectorDirListing from './DataConnectorDirListing'
 import { DataService } from './DataConnectorDirListingItemIcon';
+// import DataConnectorFilterBox from './DataConnectorFilterBox';
 
 export interface DataConnectorMetadata extends FileMetadata {
     dataService: DataService,
@@ -26,6 +27,7 @@ interface IProps {
 
 interface IState {
     dataConnectors: DataConnectorMetadata[],
+    filter: string,
 }
 
 export default class DataConnectorBrowser extends React.Component<IProps, IState> {
@@ -43,6 +45,7 @@ export default class DataConnectorBrowser extends React.Component<IProps, IState
         }
         this.state = {
             dataConnectors: Global.lastDataConnectors,
+            filter: '',
         }
     }
 
@@ -63,7 +66,9 @@ export default class DataConnectorBrowser extends React.Component<IProps, IState
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div className='jp-FileBrowser' style={this.props.style}>
+                {/* <DataConnectorFilterBox style={{marginBottom: '8px'}} onChange={(filter: string) => this.safeSetState({filter})} /> */}
                 <DataConnectorDirListing
+                    filter={this.state.filter}
                     dataConnectors={this.state.dataConnectors}
                     onOpen={this.handleOpen}
                     getSelected={this.props.getSelected && (getSelected => this.getSelected = getSelected)}
