@@ -12,6 +12,7 @@ import { DataConnectorMetadata } from './DataConnectorBrowser'
 import { Global } from '../../../Global';
 
 interface IProps {
+    filter: string
     dataConnectors: DataConnectorMetadata[]
     onOpen: (dataConnector: DataConnectorMetadata) => void
     getSelected?: (getSelected: () => DataConnectorMetadata[]) => void
@@ -100,6 +101,7 @@ export default class DataConnectorDirListing extends React.Component<IProps, ISt
                 </div>
                 <div style={{marginBottom: '6px'}} />
                 <DataConnectorDirListingContent
+                    filter={this.props.filter}
                     dataConnectors={this.props.dataConnectors}
                     handleDelete={this.props.handleDelete}
                     onOpen={this.props.onOpen}
