@@ -12,6 +12,7 @@ import { Global } from '../../../Global';
 
 export enum DataService {
     AMAZON_S3 = 'amazon s3',
+    AZURE_BLOB_STORAGE = 'azure blob storage',
     WASABI = 'wasabi',
     GOOGLE_CLOUD_STORAGE = 'google cloud storage',
     GOOGLE_DRIVE = 'google drive',
@@ -26,6 +27,7 @@ interface DataConnectorType {
 
 const dataConnectorTypes: DataConnectorType[] = [
     {dataService: DataService.AMAZON_S3,            iconClass: 'jp-s3-logo'},
+    {dataService: DataService.AZURE_BLOB_STORAGE,   iconClass: 'jp-azure-logo'},
     {dataService: DataService.WASABI,               iconClass: 'jp-wasabi-logo'},
     {dataService: DataService.GOOGLE_DRIVE,         iconClass: 'jp-drive-logo'},
     {dataService: DataService.GOOGLE_CLOUD_STORAGE, iconClass: 'jp-cloud-logo'},
