@@ -7,6 +7,7 @@
 
 import * as React from 'react'
 import { FileMetadata } from './FileBrowser'
+import { Global } from '../../../Global';
 
 interface IProps {
     file: FileMetadata
@@ -22,6 +23,7 @@ export default class BreadCrumbItem extends React.Component<IProps, IState> {
     }
 
     public render = (): JSX.Element => {
+		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <>
                 <span className='jp-BreadCrumbs-item' title={this.props.file.path} onClick={() => this.props.onOpen(this.props.file)}>
