@@ -12,6 +12,7 @@ import { caretUpIcon, caretDownIcon } from '@jupyterlab/ui-components'
 import { Global } from '../../../Global';
 
 interface IProps {
+    filter: string
     files: FileMetadata[]
     onOpen: (file: FileMetadata) => void
     getSelected: (getSelected: () => FileMetadata[]) => void
@@ -97,6 +98,7 @@ export default class DirListing extends React.Component<IProps, IState> {
                     </div>
                 </div>
                 <DirListingContent
+                    filter={this.props.filter}
                     files={this.props.files}
                     onOpen={this.props.onOpen}
                     sort={sort}
