@@ -9,7 +9,7 @@ import * as React from 'react';
 import { Global } from '../../../Global';
 
 import { Slider } from '../../../core';
-import { ComputeMetadata } from '../../../models/ComputeMetadata';
+import { ComputeConfig } from '../../../models/ComputeConfig';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import FormatUtils from '../../../utils/FormatUtils';
 
@@ -24,14 +24,14 @@ export class ComputeRating extends React.Component<IProps, IState> {
     private getValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const compute: ComputeMetadata = optumi.metadata.compute;
+		const compute: ComputeConfig = optumi.config.compute;
 		return compute.rating[1];
 	}
 
 	private async saveValue(rating: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const compute: ComputeMetadata = optumi.metadata.compute;
+		const compute: ComputeConfig = optumi.config.compute;
         compute.rating = [-1, rating, -1];
 		tracker.setMetadata(optumi);
 	}
