@@ -6,7 +6,6 @@
 **/
 
 import * as React from 'react';
-import { SubHeader } from '../../../core';
 import { Global } from '../../../Global';
 import { Expertise } from '../../../models/OptumiConfig';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
@@ -93,7 +92,6 @@ export class Simplified extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <>
-                <SubHeader title='Resource Selection'/>
                 <div
                     style={{
                         alignItems: 'center',
@@ -239,7 +237,7 @@ export class Simplified extends React.Component<IProps, IState> {
         Global.user.userInformationChanged.connect(this.handleUserChange);
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        // Set all resource levels to basic
+        // Set all resource levels to component
         optumi.config.compute.expertise = Expertise.COMPONENT;
         optumi.config.memory.expertise = Expertise.COMPONENT;
         optumi.config.storage.expertise = Expertise.COMPONENT;
