@@ -11,8 +11,8 @@ import { Global } from '../../Global';
 import { ServerConnection } from '@jupyterlab/services';
 
 import { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { ChangePasswordPopup } from './ChangePasswordPopup';
-import { CheckoutForm } from './CheckoutForm';
+// import { ChangePasswordPopup } from './ChangePasswordPopup';
+import { CreditBucketCheckoutForm } from './CreditBucketCheckoutForm';
 import { Header, Switch, TextBox, TextBoxDropdown } from '../../core';
 import FormatUtils from '../../utils/FormatUtils';
 import { Button, Divider, IconButton } from '@material-ui/core';
@@ -23,12 +23,15 @@ import { GoogleCloudStorageConnectorPopup } from '../deploy/GoogleCloudStorageCo
 import { GoogleDriveConnectorPopup } from '../deploy/GoogleDriveConnectorPopup';
 import { KaggleConnectorPopup } from '../deploy/KaggleConnectorPopup';
 import { WasabiConnectorPopup } from '../deploy/WasabiConnectorPopup';
-import { PhoneTextBox } from '../../core/PhoneTextBox';
+// import { PhoneTextBox } from '../../core/PhoneTextBox';
 import { AzureBlobStorageConnectorPopup } from '../deploy/AzureBlobStorageConnector';
 import DeleteIcon from '@material-ui/icons/Delete';
 import { FileMetadata } from '../deploy/fileBrowser/FileBrowser';
 import { FileTree } from '../FileTree';
 import moment from 'moment';
+import { BillingType } from '../../models/User';
+import { MeteredBillingCheckoutForm } from './MeteredBillingCheckoutForm';
+import { PhoneNumberFormat, PhoneNumberUtil } from 'google-libphonenumber';
 
 // Properties from parent
 interface IProps {
@@ -43,11 +46,11 @@ const emUpSub = 'Upgrade subscription to unlock'
 
 const LABEL_WIDTH = '80px'
 
-interface IAccountGeneralSubMenuState {
+interface IAccountPreferencesSubMenuState {
     switchKey: number
 }
 
-export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGeneralSubMenuState> {
+export class AccountPreferencesSubMenu extends React.Component<IProps, IAccountPreferencesSubMenuState> {
 
     constructor(props: IProps) {
         super(props);
@@ -57,13 +60,14 @@ export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGener
         }
     }
 
-    private getPasswordValue(): string { return '******' }
-    private savePasswordValue(password: string) {
-        Global.user.changePassword("", "", password);
-    }
+    // private getPasswordValue(): string { return '******' }
+    // private savePasswordValue(password: string) {
+    //     Global.user.changePassword("", "", password);
+    // }
     
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
+        const phoneUtil = PhoneNumberUtil.getInstance();
         return (
             <>
                 <div style={Object.assign({padding: '6px'}, this.props.style)}>
@@ -72,7 +76,7 @@ export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGener
                         label='Name'
                         editPressRequired
                     /> */}
-                    <div style={{display: 'inline-flex', width: '100%'}}>
+                    {/* <div style={{display: 'inline-flex', width: '100%'}}>
                         <TextBox<string>
                             style={{flexGrow: 1}}
                             getValue={this.getPasswordValue}
@@ -81,8 +85,8 @@ export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGener
                             labelWidth={LABEL_WIDTH}
                         />
                         <ChangePasswordPopup style={{margin: '8px 0px', height: '20px', fontSize: '12px', lineHeight: '12px'}}/>
-                    </div>
-                    <PhoneTextBox
+                    </div> */}
+                    {/* <PhoneTextBox
                         getValue={() => Global.user.phoneNumber}
                         saveValue={(phoneNumber: string) => {
                             if (phoneNumber == '') Global.user.notificationsEnabled = false;
@@ -93,13 +97,13 @@ export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGener
                         validOnBlur={this.props.phoneValidOnBlur}
                         label='Phone'
                         labelWidth={LABEL_WIDTH}
-                    />
+                    /> */}
                     <Switch
                         key={this.state.switchKey}
                         getValue={() => Global.user.notificationsEnabled }
                         saveValue={(notificationsEnabled: boolean) => { Global.user.notificationsEnabled = notificationsEnabled }}
-                        label='Enable SMS notifications to the listed phone number'
-                        disabled={Global.user.phoneNumber == ''}
+                        label={'Enable SMS notifications to ' + phoneUtil.format(phoneUtil.parse(Global.user.phoneNumber, 'US'), PhoneNumberFormat.INTERNATIONAL)}
+                        // disabled={Global.user.phoneNumber == ''}
                         labelBefore
                         flip
                     />
@@ -117,7 +121,7 @@ export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGener
                         labelBefore
                         flip
                     />
-                    {Global.user.showMonitoringEnabled && (
+                    {Global.user.showDownloadAllButtonEnabled && (
                         <Button 
                             variant="outlined"
                             color="primary"
@@ -396,21 +400,27 @@ export class AccountPaymentSubMenu extends React.Component<IProps, IAccountPayme
         return (
             <>
                 <div style={Object.assign({padding: '6px'}, this.props.style)}>
-                    <div style={{display: 'inline-flex', width: '100%', padding: '3px 0px'}}>
-                        <div 
-                            style={{
-                            lineHeight: '24px',
-                            margin: '0px 12px',
-                            flexGrow: 1,
-                        }}
-                        >
-                            {'Remaining balance:'}
-                        </div>
-                        <div style={{padding: '0px 6px 0px 6px'}}>
-                            {'$' + (-this.state.balance).toFixed(2)}
-                        </div>
-                    </div>
-                    <CheckoutForm />
+                    {Global.user.billingType == BillingType.CREDIT_BUCKET ? (
+                        <>
+                            <div style={{display: 'inline-flex', width: '100%', padding: '3px 0px'}}>
+                                <div 
+                                    style={{
+                                    lineHeight: '24px',
+                                    margin: '0px 12px',
+                                    flexGrow: 1,
+                                }}
+                                >
+                                    {'Remaining balance:'}
+                                </div>
+                                <div style={{padding: '0px 6px 0px 6px'}}>
+                                    {'$' + (-this.state.balance).toFixed(2)}
+                                </div>
+                            </div>
+                            <CreditBucketCheckoutForm />
+                        </>
+                    ) : (
+                        <MeteredBillingCheckoutForm />
+                    )}
                     <div style={{padding: '6px', width: '100%'}}>
                         <Button
                             variant="outlined"
@@ -719,7 +729,7 @@ export class AccountFilesSubMenu extends React.Component<IProps, IAccountFilesSu
             <>
                 <div style={Object.assign({padding: '20px 6px 6px 20px'}, this.props.style)}>
                     <div>
-                        Listed files are securely stored in the Optumi platform. If you want to delete a file hit its associated trash can icon.
+                        Listed files are securely stored in the Optumi platform. If you want to delete a file click on the associated trash can.
                         {this.getTotalUsedStorage() > 0 && <>
                             <br />
                             <br />
