@@ -6,9 +6,9 @@
 **/
 
 import * as React from 'react'
-import ReactMarkdown from 'react-markdown'
-import gfm from 'remark-gfm';
+
 import { Global } from '../../Global';
+import { Markdown as MarkdownWrapper } from '../Markdown';
 
 interface IProps {
     cell: any
@@ -23,10 +23,19 @@ export default class Markdown extends React.Component<IProps, IState> {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div className='jp-RenderedMarkdown jp-MarkdownOutput jp-RenderedHTMLCommon'>
-                <ReactMarkdown plugins={[gfm]} allowDangerousHtml >
-                    {this.props.cell.source}
-                </ReactMarkdown>
+                <MarkdownWrapper text={this.props.cell.source} />
             </div>
         )
     }
+    
+    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+        try {
+            if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
+            if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
+            return false;
+        } catch (error) {
+            return true;
+        }
+    }
 }
