@@ -27,4 +27,15 @@ export default class MarkdownCell extends React.Component<IProps, IState> {
             </div>
         )
     }
+
+    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+        try {
+            if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
+            if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
+            return false;
+        } catch (error) {
+            return true;
+        }
+    }
 }
\ No newline at end of file
