@@ -9,10 +9,12 @@ export class FileUploadConfig {
     public path: string;
     public type: 'file' | 'notebook' | 'directory';
     public mimetype: string;
+    public enabled: boolean;
 
     constructor(map: any) {
         this.path = map.path;
         this.type = map.type || 'file';
         this.mimetype = map.mimetype || 'text/plain';
+        this.enabled = map.enabled == undefined ? false : map.enabled
     }
 }
