@@ -23,11 +23,11 @@ export class GraphicsConfig {
     public boardType: string;
 
     constructor(map: any = {}, user: User = null) {
-        this.expertise = map.expertise || Expertise.BASIC;
-        this.required = map.required || false;
+        this.expertise = map.expertise || Expertise.SIMPLIFIED;
+        this.required = map.required == undefined ? false : map.required;
         this.rating = map.rating || [-1, -1, -1];
         this.score = map.score || [-1, -1, -1];
-        this.cores = map.cores || [-1, -1, -1];
+        this.cores = map.cores || [1, -1, -1];
         this.memory = map.memory || [-1, -1, -1];
         this.frequency = map.frequency || [-1, -1, -1];
         this.boardType = map.boardType || "U";  // Default is U for unspecified
