@@ -10,6 +10,7 @@ import { ComputeConfig } from "./ComputeConfig";
 import { GraphicsConfig } from "./GraphicsConfig";
 import { MemoryConfig } from "./MemoryConfig";
 import { NotificationConfig } from "./NotificationConfig";
+import { PackageConfig } from "./PackageConfig";
 import { StorageConfig } from "./StorageConfig";
 
 import { UploadConfig } from "./UploadConfig";
@@ -31,6 +32,7 @@ export class OptumiConfig {
     public storage: StorageConfig;
 	public upload: UploadConfig;
 	public notifications: NotificationConfig;
+	public package: PackageConfig;
 	public interactive: boolean;
 	public annotation: string;
 	
@@ -88,6 +90,12 @@ export class OptumiConfig {
 			case "3.8.3":
 			case "3.8.4":
 			case "3.9.0":
+			case "3.9.1":
+			case "3.9.2":
+			case "3.9.3":
+			case "3.9.4":
+			case "3.9.5":
+			case "3.9.6":
 				break;
 			default:
 				if (!version.includes("DEV")) console.log("Unknown map version: " + version);
@@ -100,8 +108,11 @@ export class OptumiConfig {
         this.storage = new StorageConfig(map.storage || {});
 		this.upload = new UploadConfig(map.upload || {});
 		this.notifications = new NotificationConfig(map.notifications || {});
+		this.package = new PackageConfig(map.package || {});
 		this.interactive = map.interactive == undefined ? false : map.interactive;
 		this.annotation = map.annotation || "";
+
+
 	}
 
 	public copy(): OptumiConfig {
