@@ -16,6 +16,12 @@ import { Machine } from './machine/Machine';
 import { Page } from '../components/deploy/RequirementsBar';
 import { Global } from '../Global';
 import { FileTracker } from './FileTracker';
+import { FileChecker } from './FileChecker';
+
+export enum BillingType {
+	CREDIT_BUCKET = 'credit bucket',
+	METERED_BILLING = 'metered billing',
+}
 
 export class User {
 	
@@ -50,6 +56,10 @@ export class User {
             responseData.maxMachines,
             responseData.machinesCap,
             responseData.userExpertise,
+            responseData.billingType as BillingType,
+			responseData.subscriptionActive,
+			responseData.lastBillPaid,
+			new Date(responseData.billingCycleAnchor),
 			responseData.compressFilesEnabled,
 			responseData.lastPage,
 			responseData.stopJobPreventEnabled,
@@ -60,8 +70,10 @@ export class User {
 			responseData.notificationsEnabled,
 			responseData.snapToInventoryEnabled,
 			responseData.showMonitoringEnabled,
+			responseData.showDownloadAllButtonEnabled,
             new AppTracker(),
 			new FileTracker(),
+			new FileChecker(),
             new Machines(machines, responseData.maxRate)
         );
         if (!newUser.unsignedAgreement) newUser.synchronize(responseData);
@@ -111,6 +123,10 @@ export class User {
     private _maxMachines: number;
     private _machinesCap: number;
 	private _userExpertise: number;
+	private _billingType: BillingType;
+	private _subscriptionActive: boolean;
+	private _lastBillPaid: boolean;
+	private _billingCycleAnchor: Date;
 	private _compressFilesEnabled: boolean;
 	private _lastPage: number;
 	private _stopJobPreventEnabled: boolean;
@@ -121,9 +137,11 @@ export class User {
 	private _notificationsEnabled: boolean;
 	private _snapToInventoryEnabled: boolean;
 	private _showMonitoringEnabled: boolean;
+	private _showDownloadAllButtonEnabled: boolean;
 
 	private _appTracker: AppTracker;
 	private _fileTracker: FileTracker;
+	private _fileChecker: FileChecker;
 	private _machines: Machines;
 
 	private _deploySubMenu: Page = Page.RESOURCES;
@@ -136,10 +154,11 @@ export class User {
         userRecommendations: number, maxRecommendations: number, recommendationsCap: number, 
         maxJobs: number, jobsCap: number, 
         maxMachines: number, machinesCap: number, 
-		userExpertise: number, compressFilesEnabled: boolean, lastPage: number, 
+		userExpertise: number, billingType: BillingType, subscriptionActive: boolean, lastBillPaid: boolean, billingCycleAnchor: Date,
+		compressFilesEnabled: boolean, lastPage: number, 
 		stopJobPreventEnabled: boolean, deleteJobPreventEnabled: boolean, noRequirementsPreventEnabled: boolean, noFileUploadsPreventEnabled: boolean, 
-		startSessionPreventEnabled: boolean, notificationsEnabled: boolean, snapToInventoryEnabled: boolean, showMonitoringEnabled: boolean,
-		appTracker: AppTracker, fileTracker: FileTracker, machines: Machines) {
+		startSessionPreventEnabled: boolean, notificationsEnabled: boolean, snapToInventoryEnabled: boolean, showMonitoringEnabled: boolean, showDownloadAllButtonEnabled: boolean,
+		appTracker: AppTracker, fileTracker: FileTracker, fileChecker: FileChecker, machines: Machines) {
         this._unsignedAgreement = unsignedAgreement === undefined ? true : unsignedAgreement;
         this._name = name;
         this._phoneNumber = phoneNumber;
@@ -165,6 +184,11 @@ export class User {
         this._machinesCap = machinesCap;
 
 		this._userExpertise = userExpertise;
+		this._billingType = billingType;
+		this._subscriptionActive = subscriptionActive;
+		this._lastBillPaid = lastBillPaid;
+		this._billingCycleAnchor = billingCycleAnchor;
+
 		this._compressFilesEnabled = compressFilesEnabled;
 		this._lastPage = lastPage;
 		this._stopJobPreventEnabled = stopJobPreventEnabled;
@@ -175,9 +199,11 @@ export class User {
 		this._notificationsEnabled = notificationsEnabled;
 		this._snapToInventoryEnabled = snapToInventoryEnabled;
 		this._showMonitoringEnabled = showMonitoringEnabled;
+		this._showDownloadAllButtonEnabled = showDownloadAllButtonEnabled;
 
 		this._appTracker = appTracker;
 		this._fileTracker = fileTracker;
+		this._fileChecker = fileChecker;
         this._machines = machines;
     }
     
@@ -414,6 +440,22 @@ export class User {
 		return this._userExpertise;
 	}
 
+	get billingType(): BillingType {
+		return this._billingType;
+	}
+
+	get subscriptionActive(): boolean {
+		return this._subscriptionActive;
+	}
+
+	get lastBillPaid(): boolean {
+		return this._lastBillPaid;
+	}
+
+	get billingCycleAnchor(): Date {
+		return this._billingCycleAnchor;
+	}
+
 	get compressFilesEnabled(): boolean {
 		return this._compressFilesEnabled;
 	}
@@ -526,12 +568,8 @@ export class User {
 		return this._showMonitoringEnabled;
 	}
 
-	set showMonitoringEnabled(showMonitoringEnabled: boolean) {
-		if (showMonitoringEnabled === this._showMonitoringEnabled) {
-			return;
-		}
-		this._showMonitoringEnabled = showMonitoringEnabled;
-		this.setUserInformation("showMonitoringEnabled", showMonitoringEnabled.toString());
+	get showDownloadAllButtonEnabled(): boolean {
+		return this._showDownloadAllButtonEnabled;
 	}
 
 	get fileTracker(): FileTracker {
@@ -542,6 +580,10 @@ export class User {
 		return this._appTracker;
 	}
 
+	get fileChecker(): FileChecker {
+		return this._fileChecker;
+	}
+
 	set machines(machines: Machines) {
 		if (machines === this._machines) {
 			return;
