@@ -206,12 +206,6 @@ export class App {
 			var mod: Module = new Module(module.uuid, module.machine ? Object.setPrototypeOf(module.machine, Machine.prototype) : null, module.token, output, updates, outputFiles, monitoring, lastPatch);
 			mod.applyPatch = app.applyPatch;
 			app._modules.push(mod);
-			if (mod.modStatus == Status.RUNNING) {
-                // The module is still running
-                if (!app._initializing.completed || !app._preparing.completed || !app._running.completed) {
-					if (app.interactive) mod.startSessionHandler();
-                }
-			}
 		}
 		return app;
 	}
@@ -231,7 +225,7 @@ export class App {
 				// Special case a warning when we fail to get a machine and start trying a new one
 				if ((body.preparing[i] as string).startsWith('Machine unavailable, trying another')) {
 					if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-					Global.snackbarChange.emit(new Snackbar(
+					Global.snackbarEnqueue.emit(new Snackbar(
 						this.name + " (" +  this.annotationOrRunNum + "): " + body.preparing[i],
 						{ variant: 'warning', }
 					));
@@ -243,21 +237,16 @@ export class App {
 			for (let i = 0; i < body.running.length; i++) {
 				if (body.running[i] == 'Completed') {
 					if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-					Global.snackbarChange.emit(new Snackbar(
+					Global.snackbarEnqueue.emit(new Snackbar(
 						this.name + " (" + this.annotationOrRunNum + "): " + body.running[i],
 						{ variant: 'success', }
 					));
 				} else if (body.running[i] == 'Failed') {
 					if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-					Global.snackbarChange.emit(new Snackbar(
+					Global.snackbarEnqueue.emit(new Snackbar(
 						this.name + " (" + this.annotationOrRunNum + "): " + body.running[i],
 						{ variant: 'error', }
 					));
-				} else if (body.running[i] == 'Terminated') {
-					// We will proactively disconnect the session here
-					for (var module of this._modules) {
-						module.stopSessionHandler();
-					}
 				}
 				this._running.addUpdate(new Update(body.running[i], body.runningmod[i]), false);
 			}
@@ -377,13 +366,6 @@ export class App {
         }
         return undefined;
 	}
-	
-	get sessionPort(): string {
-        for (let mod of this.modules) {
-			if (mod.sessionPort) return mod.sessionPort;
-        }
-        return undefined;
-    }
 
     get machine(): Machine {
         for (let mod of this.modules) {
@@ -411,6 +393,7 @@ export class App {
 			method: 'POST',
 			body: JSON.stringify({
 				nbConfig: JSON.stringify(this._config),
+				includeExisting: true,
 			}),
 		};
 		return ServerConnection.makeRequest(
@@ -523,7 +506,6 @@ export class App {
 						mod.applyPatch = this.applyPatch
 						mod.updateNotebook = this.updateNotebook
 						this._modules.push(mod);
-						if (this.interactive) mod.startSessionHandler();
 					}
 					if (body.files) {
 						for (let i = 0; i < body.files.length; i++) {
@@ -547,7 +529,7 @@ export class App {
 					}
 					if (body.snackbar) {
 						if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-						Global.snackbarChange.emit(new Snackbar(
+						Global.snackbarEnqueue.emit(new Snackbar(
                             this.name + " (" + this.annotationOrRunNum + "): " + body.snackbar,
                             { variant: 'error', }
                         ));
