@@ -9,7 +9,7 @@ import { Button, Dialog, DialogContent, IconButton, Tab, Tabs, withStyles } from
 import * as React from 'react';
 import { Global } from '../../Global';
 import PopupIcon from '@material-ui/icons/MoreVert';
-import MuiDialogTitle from '@material-ui/core/DialogTitle';
+import DialogTitle from '@material-ui/core/DialogTitle';
 import { CSSProperties } from '@material-ui/core/styles/withStyles';
 import CloseIcon from '@material-ui/icons/Close';
 import { App } from './App';
@@ -24,7 +24,6 @@ import Notebook from '../../core/notebook/Notebook';
 import FileServerUtils from '../../utils/FileServerUtils';
 import { NotificationContent } from '../../core/NotificationContent';
 import { OptumiConfig } from '../OptumiConfig';
-import ExtraInfo from '../../utils/ExtraInfo';
 import { ResourceGraph } from '../../core/ResourceGraph';
 
 const StyledDialog = withStyles({
@@ -95,7 +94,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
     }
 
     private openSession = () => {
-        window.open('http://' + window.location.hostname + ':' + this.props.app.sessionPort + '?token=' + this.props.app.sessionToken, '_blank');
+        window.open('https://' + this.props.app.machine.dnsName + ':54321?token=' + this.props.app.sessionToken, '_blank');
     }
 
     private openAsNewNotebook = async () => {
@@ -155,7 +154,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
 					onClose={this.handleClose}
                     scroll='paper'
 				>
-					<MuiDialogTitle
+					<DialogTitle
 					    disableTypography
                         style={{
                             display: 'inline-flex',
@@ -170,7 +169,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                             minWidth: '150px',
                             fontSize: '16px',
                             fontWeight: 'bold',
-                            paddingRight: '12px', // this is 6px counteracting the MuiDialogTitle padding and 6px aligning the padding to the right of the tabs
+                            paddingRight: '12px', // this is 6px counteracting the DialogTitle padding and 6px aligning the padding to the right of the tabs
                         }}>
                             <div style={{margin: 'auto', paddingLeft: '12px'}}>
             					{app.interactive ? "Session" : "Job"}
@@ -193,19 +192,17 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     Open session
                                 </Button>
                             )}
-                            <ExtraInfo reminder='Create as a new notebook' >
-                                <Button
-                                    style={{margin: '6px'}}
-                                    disableElevation
-                                    variant='contained'
-                                    color='primary'
-                                    onClick={this.openAsNewNotebook}
-                                    disabled={app.getAppStatus() != Status.COMPLETED}
-                                    endIcon={<OpenInNewIcon />}
-                                >
-                                    Save + Open
-                                </Button>
-                            </ExtraInfo>
+                            <Button
+                                style={{margin: '6px'}}
+                                disableElevation
+                                variant='contained'
+                                color='primary'
+                                onClick={this.openAsNewNotebook}
+                                disabled={app.getAppStatus() != Status.COMPLETED}
+                                endIcon={<OpenInNewIcon />}
+                            >
+                                Open as a new notebook
+                            </Button>
 						</div>
                         <IconButton
                             onClick={this.handleClose}
@@ -225,7 +222,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                 }}
                             />
                         </IconButton>
-					</MuiDialogTitle>
+					</DialogTitle>
                     <ShadowedDivider />
                     <div style={{display: 'flex', height: 'calc(100% - 60px - 2px'}}>
                         <div style={{width: '150px'}}>
